==> wpewebkit_2.34.2.orig.tar.xz: wpewebkit-2.34.2/Source/bmalloc/libpas/src/libpas/pas_compact_atomic_bitfit_global_size_class_ptr.h <==
/*
 * Copyright (c) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H
#define PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H

#include "pas_compact_atomic_ptr.h"

PAS_BEGIN_EXTERN_C;

struct pas_bitfit_global_size_class;
typedef struct pas_bitfit_global_size_class pas_bitfit_global_size_class;

PAS_DEFINE_COMPACT_ATOMIC_PTR(pas_bitfit_global_size_class,
                              pas_compact_atomic_bitfit_global_size_class_ptr);

PAS_END_EXTERN_C;

#endif /* PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H */

==> wpewebkit_2.46.5.orig.tar.xz: wpewebkit-2.46.5/Source/bmalloc/libpas/src/libpas/pas_compact_atomic_bitfit_global_size_class_ptr.h <==
/*
 * Copyright (c) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H
#define PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H

#include "pas_compact_atomic_ptr.h"

PAS_BEGIN_EXTERN_C;

struct pas_bitfit_size_class;
typedef struct pas_bitfit_size_class pas_bitfit_size_class;

PAS_DEFINE_COMPACT_ATOMIC_PTR(pas_bitfit_size_class,
                              pas_compact_atomic_bitfit_size_class_ptr);

PAS_END_EXTERN_C;

#endif /* PAS_COMPACT_ATOMIC_BITFIT_GLOBAL_SIZE_CLASS_PTR_H */
